*****************************************************
* Sources of Time Preference and Time-Inconsistency	*
* Gine, Goldberg, Silverman and Yang				*
*****************************************************

***********************************************************************
clear all
capture log close
set more off

log using balance.log, replace




#delimit ;

global d=1;


if $d==1 {;
	global data "/Users/Jess/Dropbox/Malawi/malawi_db/UndoingCommitment/data/";
	global out "/Users/Jess/Dropbox/Malawi/malawi_db/UndoingCommitment/results/replication/";
	};

use "${data}GGSY_data.dta", clear;

***************;
*Appendix Table 1;
***************;


**Generate Variables Indicating Higher Elasticities of Substitution in the Far Time Frame* ;
;

gen moreelasfar=1 if  elas_diff_average>0 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasfar=0 if moreelasfar==. & elas_diff_average~=. & fracpb_2!=.;

gen moreelasfar_2=1 if  elas_diff_average>0.1 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasfar_2=0 if moreelasfar_2==. & elas_diff_average~=. & fracpb_2!=.;

**Generate Variables Indicating Higher Elasticities of Substitution in the Near Time Frame*;
;

gen moreelasnear=1 if  elas_diff_average<0 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasnear=0 if moreelasnear==. & elas_diff_average~=. & fracpb_2!=.;

gen moreelasnear_2=1 if  elas_diff_average<-0.1 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasnear_2=0 if moreelasnear_2==. & elas_diff_average~=. & fracpb_2!=.;

label var moreelasfar "More elastic in the far horizon";
label var moreelasfar_2 "More elastic in the far horizon";
label var moreelasnear "More elastic in the near horizon";
label var moreelasnear_2 "More elastic in the near horizon";


;

gen fracpb_2_nonimp_ME = fracpb_2_nonimp* moreelasfar_2;
gen fracpb_2_x_target_lag_2_6=fracpb_2*target_lag_2_6;
gen target_lag_2_6_x_MEfar=target_lag_2_6*moreelasfar_2;
gen fracpb_2_target_lag_2_6_MEfar=fracpb_2_nonimp*target_lag_2_6*moreelasfar_2;


gen fracfb_2_nonimp_ME = fracfb_2_nonimp* moreelasnear_2;

label var fracpb_2_nonimp_ME "Fraction present-biased * more elastic in the far horizon";
label var fracpb_2_x_target_lag_2_6 "Fraction present-biased * days to first disbursement < 6";
label var target_lag_2_6_x_MEfar "Days to first disbursement < 6 * more elastic in the far horizon";
label var fracpb_2_target_lag_2_6_MEfar "Fraction present-biased * more elastic in the far horizon * days to first disbursement < 6";
label var fracfb_2_nonimp_ME "Fraction future-biased * more elastic in near horizon";




* dummy for missing baseline vars;
xi: reg dC_1
fracpb_2_nonimp 
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income 
spousebias_nonimp relatives
improreturn 
male younger middleage some_primary primary morethan_primary havemaize wealth_bline timeprefA qualflag  
treatment_1 treatment_2 treatment_3 treatment_4 treatment_5 treatment_6 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
a1 a4
;
gen missing_baselinevars = 1 if ~e(sample);



for any
revised_fb revised_pb
target_lag target_lag_2_6 
deathinfam delta_income 
spouse_fracpb_2
spouse_sooner_mk
spousebias_imp
spousebias_nonimp
spousebias_all_sooner
wealth_bline hh_tot_bank_bline hh_cash_bline sell_items_bline sell_animals_bline exp_income_bline exp_revenue_bline
dC_1
a1 a4
improreturn
:
replace X = . 
if 
dC_1==. 
| missing_baselinevars==1 
| actual_lag==.
| actual_lag==0
| z13_month==3
;


** Age;

su a1, d;
gen age=a1;

** Years of schooling;

su a4, d;
gen educ=a4;
replace educ=0 if educ==77;



;;;
* BALANCE TEST FOR TARGET LAG AND IMPRORETURN ;;;
;;;



for any 
fracfb_2_nonimp frac_sooner  moreelasfar_2
frac_posdcs wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
male age educ havemaize wealth_bline 
hh_tot_bank_bline hh_cash_bline sell_items_bline sell_animals_bline 
:
\\\\\\
** Baseline variable: X
\
reg X target_lag_2_6, robust \
reg X target_lag , robust \
reg X target_lag_2_6 target_lag_7_11, robust \
testparm target_lag_2_6 target_lag_7_11 \
reg X 
target_lag_2
target_lag_3
target_lag_4
target_lag_5
target_lag_6
target_lag_7
target_lag_8
target_lag_9
target_lag_10
target_lag_11
target_lag_12
target_lag_13
target_lag_14
target_lag_15
, robust 
;

for any 
fracfb_2_nonimp  frac_sooner moreelasfar_2
frac_posdcs wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
male age educ havemaize wealth_bline 
hh_tot_bank_bline hh_cash_bline sell_items_bline sell_animals_bline 
:
\\\\\\
** Baseline variable: X
\
reg X improreturn, robust \ 
reg X improreturn25 improreturn50 improreturn75 improreturn100, robust \ 
testparm improreturn25 improreturn50 improreturn75 improreturn100 \
;


;;;;;
*** REGRESSIONS FOR BALANCE TABLE;
;;;




for any 
fracfb_2_nonimp frac_sooner moreelasfar_2
frac_posdcs wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
male age educ havemaize wealth_bline 
:
\\\\\\
** Baseline variable: X
\
reg X target_lag_2_6, robust \ eststo X
;

estout 
fracfb_2_nonimp frac_sooner moreelasfar_2
frac_posdcs wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
male age educ havemaize wealth_bline 
using "${out}balance_target_lag_july2013.xls",  
replace starlevels(* 0.10 ** 0.05 *** 0.01) cells(b(star fmt(3)) se(par fmt(3))) stats(r2 N, fmt(4) label(R-squared)) unstack
;
eststo clear;

for any 
fracfb_2_nonimp frac_sooner moreelasfar_2
frac_posdcs wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
male age educ havemaize wealth_bline 
:
\\\\\\
** Baseline variable: X
\
reg X improreturn, robust \ eststo X
;

estout 
fracfb_2_nonimp frac_sooner moreelasfar_2
frac_posdcs wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
male age educ havemaize wealth_bline 
using "${out}app1.xls",  
replace starlevels(* 0.10 ** 0.05 *** 0.01) cells(b(star fmt(3)) se(par fmt(3))) stats(r2 N, fmt(4) label(R-squared)) unstack
;

estimates clear;



************************;
*Appendix Table 4;
************************;

xi: reg dC_1
improreturn
fracfb_2_nonimp
frac_sooner target_lag_2_6
moreelasnear_2
fracfb_2_nonimp_ME
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
spousebias_nonimp relatives
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens spouse_finlit_total spouse_frac_posdcs
i.z13_month, robust;
estimates store table4_app1;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);


estout table4_* using "${out}app4.xls", replace 
		numbers label
		title("Table 6.  Determinants of Revisions towards Sooner")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a pval, fmt(0 2 2) labels("Observations" "Adjusted R-squared" "P-value for fin lit")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individual included in revisit sample. All regressions also include the following controls: indicators for each treatments implemented in Brune, Gine, Goldberg, and Yang (2011); indicator for whether near choices were presented before far choices in baseline survey; indicator for project staff error in presentation of baseline allocation upon revisiting. Spousal characteristics controls are: fraction present biased for all choices, indicators for age category, indicators for education category, word recall, ravens score, financial literacy score, and fraction of choices adhering to law of demand.") ;

estout table4_* using "${out}app4.tex", replace 
		numbers label
drop (spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs  _Iz13_month_2)
		style(tex)
		title("Table 6.  Determinants of Revisions towards Sooner")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a, fmt(0 2) labels("Observations" "Adjusted R-squared")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individual included in revisit sample. All regressions also include the following controls: indicators for each treatments implemented in Brune, Gine, Goldberg, and Yang (2011); indicator for whether near choices were presented before far choices in baseline survey; indicator for project staff error in presentation of baseline allocation upon revisiting. Spousal characteristics controls are: fraction present biased for all choices, indicators for age category, indicators for education category, word recall, ravens score, financial literacy score, and fraction of choices adhering to law of demand.") ;

		
estimates clear;

************************;
*Appendix Table 8;
************************;

preserve;
keep if dC_1!=. & actual_lag!=. & actual_lag!=0;
drop if tot_num_posdcs<=6;


xi: reg dC_1 
improreturn 
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
i.z13_month, robust;
estimates store table6_1;

xi: reg dC_1 
improreturn 
fracpb_2_nonimp target_lag_2_6 frac_sooner fracpb_2_nonimp_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
i.z13_month, robust;
estimates store table6_2;

xi: reg dC_1 
improreturn 
fracpb_2_nonimp target_lag_2_6 frac_sooner fracpb_2_nonimp_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
i.z13_month, robust;
estimates store table6_3;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);


xi: reg dC_1 
improreturn 
fracpb_2_nonimp target_lag_2_6 frac_sooner fracpb_2_nonimp_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
i.z13_month, robust;
estimates store table6_4;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);

xi: reg dC_1 
improreturn 
fracpb_2_nonimp target_lag_2_6 frac_sooner fracpb_2_nonimp_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
spousebias_nonimp relatives
i.z13_month, robust;
estimates store table6_5;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);

xi: reg dC_1 
improreturn 
fracpb_2_nonimp target_lag_2_6 frac_sooner fracpb_2_nonimp_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
spousebias_nonimp relatives
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens spouse_finlit_total spouse_frac_posdcs
i.z13_month, robust;
estimates store table6_6;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);


estout table6_* using "${out}app8.xls", replace 
		numbers label
		title("Table 5.  Determinants of Revisions towards Sooner")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a pval, fmt(0 2 2) labels("Observations" "Adjusted R-squared" "P-value for fin lit")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individual included in revisit sample. All regressions also include the following controls: indicators for each treatments implemented in Brune, Gine, Goldberg, and Yang (2011); indicator for whether near choices were presented before far choices in baseline survey; indicator for project staff error in presentation of baseline allocation upon revisiting. Spousal characteristics controls are: fraction present biased for all choices, indicators for age category, indicators for education category, word recall, ravens score, financial literacy score, and fraction of choices adhering to law of demand.") ;

estout table6_* using "${out}app8.tex", replace 
		numbers label
		style(tex)
		title("Table 5.  Determinants of Revisions towards Sooner")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a, fmt(0 2) labels("Observations" "Adjusted R-squared")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individual included in revisit sample. All regressions also include the following controls: indicators for each treatments implemented in Brune, Gine, Goldberg, and Yang (2011); indicator for whether near choices were presented before far choices in baseline survey; indicator for project staff error in presentation of baseline allocation upon revisiting. Spousal characteristics controls are: fraction present biased for all choices, indicators for age category, indicators for education category, word recall, ravens score, financial literacy score, and fraction of choices adhering to law of demand.") ;


restore;


************************;
*Appendix Table 7;
************************;



xi: reg dC_1
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
i.z13_month if male==0 & (dC_1!=. & actual_lag!=. & actual_lag!=0), robust;
estimates store table9_1;

xi: reg dC_1
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
i.z13_month if male==1 & (dC_1!=. & actual_lag!=. & actual_lag!=0), robust;
estimates store table9_2;


estout table9_* using "${out}app7.xls", replace 
		numbers label
		title("Table 8.  Determinants of Inclusion in Revisit Sample")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a, fmt(0 2) labels("Observations" "Adjusted R-squared")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individuals targeted for inclusion in revisit sample. Column 1 restricts to females in the revisit sample.  Column 2 restricts to males in the revisit sample.  See Table 6 for other notes.") ;

estout table9_* using "${out}app7.tex", replace 
		numbers label
drop (spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs  _Iz13_month_2 )
		style(tex)
		title("Table 6.  Determinants of Inclusion in Revisit Sample")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a, fmt(0 2) labels("Observations" "Adjusted R-squared")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individuals targeted for inclusion in revisit sample. Column 1 restricts to females in the revisit sample.  Column 2 restricts to males in the revisit sample.  See Table 6 for other notes.") ;



* Test of difference of male vs. female coeffs;

qui xi: reg dC_1
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
male younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
i.z13_month if (dC_1!=. & actual_lag!=. & actual_lag!=0), robust
;
keep if e(sample);
keep if (dC_1!=. & actual_lag!=. & actual_lag!=0);


keep dC_1
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
male younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
z13_month 
;

preserve;
keep if male==0;
for any
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
z13_month 
:
rename X X_f
;
save data_female_temp, replace;

restore;
keep if male==1;
for any
fracpb_2_nonimp target_lag_2_6  moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
z13_month 
:
rename X X_m
;
save data_male_temp, replace;

append using data_female_temp;

for any
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
younger middleage some_primary primary morethan_primary havemaize wealth_bline 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
z13_month 
:
replace X_f = 0 if X_f==. \
replace X_m = 0 if X_m==. 
;

reg dC_1
fracpb_2_nonimp_m target_lag_2_6_m moreelasfar_2_m fracpb_2_nonimp_ME_m
frac_posdcs_m frac_sooner_m wrdrecal_1_m ravens_m finlit_total_m
deathinfam_m  delta_income_m
spousebias_nonimp_m relatives_m
improreturn_m 
younger_m middleage_m some_primary_m primary_m morethan_primary_m havemaize_m wealth_bline_m 
spouse_fracpb_2_m spouse_young_m spouse_middleage_m spouse_some_primary_m spouse_morethan_primary_m spouse_primary_m spouse_wrdrecal_1_m spouse_ravens_m
spouse_finlit_total_m spouse_frac_posdcs_m
i.z13_month_m 

fracpb_2_nonimp_f target_lag_2_6_f moreelasfar_2_f fracpb_2_nonimp_ME_f
frac_posdcs_f frac_sooner_f wrdrecal_1_f ravens_f finlit_total_f
deathinfam_f  delta_income_f
spousebias_nonimp_f relatives_f
improreturn_f 
younger_f middleage_f some_primary_f primary_f morethan_primary_f havemaize_f wealth_bline_f 
spouse_fracpb_2_f spouse_young_f spouse_middleage_f spouse_some_primary_f spouse_morethan_primary_f spouse_primary_f spouse_wrdrecal_1_f spouse_ravens_f
spouse_finlit_total_f spouse_frac_posdcs_f
i.z13_month_f

, robust
;
for any 
fracpb_2_nonimp target_lag_2_6 moreelasfar_2 fracpb_2_nonimp_ME
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
deathinfam  delta_income
spousebias_nonimp relatives
improreturn 
younger middleage some_primary primary morethan_primary havemaize wealth_bline 
:
test X_m = X_f
; 
		
				

************************;
*Appendix Table 3;
************************;

use "${data}GGSY_data.dta", clear;


**Generate Variables Indicating Higher Elasticities of Substitution in the Far Time Frame* ;
;

gen moreelasfar=1 if  elas_diff_average>0 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasfar=0 if moreelasfar==. & elas_diff_average~=. & fracpb_2!=.;

gen moreelasfar_2=1 if  elas_diff_average>0.1 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasfar_2=0 if moreelasfar_2==. & elas_diff_average~=. & fracpb_2!=.;

**Generate Variables Indicating Higher Elasticities of Substitution in the Near Time Frame*;
;

gen moreelasnear=1 if  elas_diff_average<0 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasnear=0 if moreelasnear==. & elas_diff_average~=. & fracpb_2!=.;

gen moreelasnear_2=1 if  elas_diff_average<-0.1 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasnear_2=0 if moreelasnear_2==. & elas_diff_average~=. & fracpb_2!=.;

label var moreelasfar "More elastic in the far horizon";
label var moreelasfar_2 "More elastic in the far horizon";
label var moreelasnear "More elastic in the near horizon";
label var moreelasnear_2 "More elastic in the near horizon";

********;
********;
*New variables created by DS;
********;
********;

;

gen fracpb_2_ME = fracpb_2* moreelasfar_2;
gen fracpb_2_x_target_lag_2_6=fracpb_2*target_lag_2_6;
gen target_lag_2_6_x_MEfar=target_lag_2_6*moreelasfar_2;
gen fracpb_2_target_lag_2_6_MEfar=fracpb_2*target_lag_2_6*moreelasfar_2;


gen fracfb_2_ME = fracfb_2_nonimp* moreelasnear_2;

label var fracpb_2_ME "Fraction present-biased * more elastic in the far horizon";
label var fracpb_2_x_target_lag_2_6 "Fraction present-biased * days to first disbursement < 6";
label var target_lag_2_6_x_MEfar "Days to first disbursement < 6 * more elastic in the far horizon";
label var fracpb_2_target_lag_2_6_MEfar "Fraction present-biased * more elastic in the far horizon * days to first disbursement < 6";
label var fracfb_2_ME "Fraction future-biased * more elastic in near horizon";



drop if dC_1==. | actual_lag==. | actual_lag==0;


***REDEFINE FRAC SOONER to include implemented choice;


drop frac_sooner num_sooner;

gen num_sooner=b1_100+b2_100+b3_100+b4_100+b5_100+b6_100+b7_100+b8_100+b9_100+b10_100;
gen frac_sooner=num_sooner/200;
label var frac_sooner "Fraction of tokens allocated to `sooner'";


sum frac_sooner, d;

xi: reg dC_1 
improreturn 
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
i.z13_month, robust;
estimates store table6_1;

xi: reg dC_1 
improreturn 
fracpb_2 target_lag_2_6 frac_sooner fracpb_2_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
i.z13_month, robust;
estimates store table6_2;

xi: reg dC_1 
improreturn 
fracpb_2 target_lag_2_6 frac_sooner fracpb_2_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
i.z13_month, robust;
estimates store table6_3;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);


xi: reg dC_1 
improreturn 
fracpb_2 target_lag_2_6 frac_sooner fracpb_2_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
i.z13_month, robust;
estimates store table6_4;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);


xi: reg dC_1 
improreturn 
fracpb_2 target_lag_2_6 frac_sooner fracpb_2_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
spousebias_nonimp relatives
i.z13_month, robust;
estimates store table6_5;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);


xi: reg dC_1 
improreturn 
fracpb_2 target_lag_2_6 frac_sooner fracpb_2_ME moreelasfar_2
male younger middleage some_primary primary morethan_primary 
havemaize wealth_bline
frac_posdcs wrdrecal_1 ravens finlit_total
deathinfam delta_income
spousebias_nonimp relatives
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens spouse_finlit_total spouse_frac_posdcs
i.z13_month, robust;
estimates store table6_6;
qui test frac_posdcs wrdrecal_1 ravens finlit_total;
estadd scalar pval=r(p);




estout table6_* using "${out}app3.xls", replace 
		numbers label
		title("Table 6.  Determinants of Revisions towards Sooner")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a pval, fmt(0 2 2) labels("Observations" "Adjusted R-squared" "P-value for fin lit")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individual included in revisit sample. All regressions also include the following controls: indicators for each treatments implemented in Brune, Gine, Goldberg, and Yang (2011); indicator for whether near choices were presented before far choices in baseline survey; indicator for project staff error in presentation of baseline allocation upon revisiting. Spousal characteristics controls are: fraction present biased for all choices, indicators for age category, indicators for education category, word recall, ravens score, financial literacy score, and fraction of choices adhering to law of demand.") ;

estimates clear;




************************;
*Appendix Table 5;
************************;	

use "${data}GGSY_data.dta", clear;	


**Generate Variables Indicating Higher Elasticities of Substitution in the Far Time Frame* ;
;

gen moreelasfar=1 if  elas_diff_average>0 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasfar=0 if moreelasfar==. & elas_diff_average~=. & fracpb_2!=.;

gen moreelasfar_2=1 if  elas_diff_average>0.1 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasfar_2=0 if moreelasfar_2==. & elas_diff_average~=. & fracpb_2!=.;

**Generate Variables Indicating Higher Elasticities of Substitution in the Near Time Frame*;
;

gen moreelasnear=1 if  elas_diff_average<0 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasnear=0 if moreelasnear==. & elas_diff_average~=. & fracpb_2!=.;

gen moreelasnear_2=1 if  elas_diff_average<-0.1 & elas_diff_average~=. & fracpb_2!=.;
replace moreelasnear_2=0 if moreelasnear_2==. & elas_diff_average~=. & fracpb_2!=.;

label var moreelasfar "More elastic in the far horizon";
label var moreelasfar_2 "More elastic in the far horizon";
label var moreelasnear "More elastic in the near horizon";
label var moreelasnear_2 "More elastic in the near horizon";


;

gen fracpb_2_nonimp_ME = fracpb_2_nonimp* moreelasfar_2;
gen fracpb_2_x_target_lag_2_6=fracpb_2*target_lag_2_6;
gen target_lag_2_6_x_MEfar=target_lag_2_6*moreelasfar_2;
gen fracpb_2_target_lag_2_6_MEfar=fracpb_2_nonimp*target_lag_2_6*moreelasfar_2;


gen fracfb_2_nonimp_ME = fracfb_2_nonimp* moreelasnear_2;

label var fracpb_2_nonimp_ME "Fraction present-biased * more elastic in the far horizon";
label var fracpb_2_x_target_lag_2_6 "Fraction present-biased * days to first disbursement < 6";
label var target_lag_2_6_x_MEfar "Days to first disbursement < 6 * more elastic in the far horizon";
label var fracpb_2_target_lag_2_6_MEfar "Fraction present-biased * more elastic in the far horizon * days to first disbursement < 6";
label var fracfb_2_nonimp_ME "Fraction future-biased * more elastic in near horizon";


preserve;

drop attrit*;
keep if target_lag~=.;

xi: reg
fracpb_2_nonimp 
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
improreturn 
male younger middleage some_primary primary morethan_primary havemaize wealth_bline timeprefA qualflag  
treatment_1 treatment_2 treatment_3 treatment_4 treatment_5 treatment_6 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
i.z13_month if z13_month~=3
;
keep if e(sample);


* ATTRITION VARIABLES;

gen insamp=1 if target_lag~=.;
replace insamp=0 if target_lag~=. & actual_lag==.;
tab insamp;


xi: reg insamp
fracpb_2_nonimp target_lag_2_6 moreelasfar_2
frac_posdcs frac_sooner wrdrecal_1 ravens finlit_total
spousebias_nonimp relatives
improreturn 
male younger middleage some_primary primary morethan_primary havemaize wealth_bline timeprefA qualflag  
treatment_1 treatment_2 treatment_3 treatment_4 treatment_5 treatment_6 
spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs
i.z13_month if z13_month~=3, robust
;
estimates store table8;

estout table8 using "${out}app5.xls", replace 
		numbers label
		title("Table 8.  Determinants of Inclusion in Revisit Sample")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a, fmt(0 2) labels("Observations" "Adjusted R-squared")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individuals targeted for inclusion in revisit sample. Dependent variable has mean of 0.915. Right-hand-side variables are identical to column 6, Table 6, except for omission of shock variables (death in family and shortfall in expected household income), because shock variables are not available for attriters. See Table 6 for other notes.") ;

estout table8 using "${out}app5.tex", replace 
		numbers label
drop (spouse_fracpb_2 spouse_young spouse_middleage spouse_some_primary spouse_morethan_primary spouse_primary spouse_wrdrecal_1 spouse_ravens
spouse_finlit_total spouse_frac_posdcs treatment_1 treatment_2 treatment_3 treatment_4 treatment_5 treatment_6 timeprefA _Iz13_month_2 qualflag)
		style(tex)
		title("Table 8.  Determinants of Inclusion in Revisit Sample")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(60) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a, fmt(0 2) labels("Observations" "Adjusted R-squared")) legend 		
		postfoot("" "Robust standard errors in parentheses. Notes: Unit of observation is individuals targeted for inclusion in revisit sample. Dependent variable has mean of 0.915. Right-hand-side variables are identical to column 6, Table 6, except for omission of shock variables (death in family and shortfall in expected household income), because shock variables are not available for attriters. See Table 6 for other notes.") ;

restore;
		



************************;
*Appendix Table 2;
************************;

use "${data}GGSY_data_long.dta", clear;


xi: reg dln_c_n r i.z13_month, cluster(respid);
estimates store table4_1;


xi: reg dln_c_n r male younger middleage some_primary primary morethan_primary havemaize lnwealth_bline wrdrecal_1 ravens finlit_total relatives i.z13_month, cluster(respid);
estimates store table4_2;
qui test male younger middleage some_primary primary morethan_primary havemaize lnwealth_bline wrdrecal_1 ravens finlit_total relatives;
estadd scalar pval=r(p);

xi: reg dln_c_f r i.z13_month, cluster(respid);
estimates store table4_3;

xi: reg dln_c_f r male younger middleage some_primary primary morethan_primary havemaize lnwealth_bline wrdrecal_1 ravens finlit_total relatives i.z13_month, cluster(respid);
estimates store table4_4;
qui test male younger middleage some_primary primary morethan_primary havemaize lnwealth_bline wrdrecal_1 ravens finlit_total relatives;
estadd scalar pval=r(p);


keep respid dln_c_n r male younger middleage some_primary primary morethan_primary havemaize lnwealth_bline wrdrecal_1 ravens finlit_total relatives z13_month;

sort respid;
ren dln_c_n dln_c;

save "${data}data_temp_n.dta", replace;

use "${data}GGSY_data_long.dta", clear;

keep respid dln_c_f r male younger middleage some_primary primary morethan_primary havemaize lnwealth_bline wrdrecal_1 ravens finlit_total relatives z13_month;
 



estout table4_* using "${out}app2.xls", replace 
		numbers label
		title("Table 4.  Determinants of Change in ln(c) From Sooner to Later")
		drop (_Iz13_month_2)
		collabels(, none) mlabels(, none)
		posthead("") varwidth(40) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a pval, fmt(0 2 2) labels("Observations" "Adjusted R-squared" "P-value")) legend 		
		postfoot("" "Note: Dependent variable is natural log of later allocation minus natural log of sooner allocation. Unit of observation is choices made by respondents in baseline sample (10 choices per study respondent) that vary in time frame and rate of return for waiting; corner solutions excluded from regression sample. All allocations made in Jan-Feb 2010.") ;

estout table4_* using "${out}app2.tex", replace 
		numbers label
		drop (_Iz13_month_2)
		style(tex)
		title("Table 4.  Determinants of Change in ln(c) From Sooner to Later")
		collabels(, none) mlabels(, none)
		posthead("") varwidth(40) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(N r2_a pval, fmt(0 2 2) labels("Observations" "Adjusted R-squared" "P-value")) legend 		
		postfoot("" "Note: Dependent variable is natural log of later allocation minus natural log of sooner allocation. Unit of observation is choices made by respondents in baseline sample (10 choices per study respondent) that vary in time frame and rate of return for waiting; corner solutions excluded from regression sample. All allocations made in Jan-Feb 2010.") ;

estimates clear;		

		
